==> racer-0.1.1.tgz: package/examples/letters/server.js <==
var app, col, colors, defaultLetters, express, fs, gzip, racer, row, store;
express = require('express');
gzip = require('connect-gzip');
fs = require('fs');
racer = require('racer');
app = express.createServer().use(express.favicon()).use(gzip.staticGzip(__dirname));
store = racer.createStore({
  redis: {
    db: 10
  },
  listen: app,
  namespace: 'letters'
});
store.flush();
racer.js({
  entry: __dirname + '/client.js'
}, function(js) {
  return fs.writeFileSync(__dirname + '/script.js', js);
});
colors = ['red', 'yellow', 'blue', 'orange', 'green'];
defaultLetters = {};
for (row = 0; row <= 4; row++) {
  for (col = 0; col <= 25; col++) {
    defaultLetters[row * 26 + col] = {
      color: colors[row],
      value: String.fromCharCode(65 + col),
      position: {
        left: col * 24 + 72,
        top: row * 32 + 8
      }
    };
  }
}
defaultLetters = JSON.stringify(defaultLetters);
app.get('/:room?', function(req, res) {
  var model, room, _room;
  room = req.params.room;
  if (!(room && /^[-\w ]+$/.test(room))) {
    return res.redirect('/lobby');
  }
  _room = room.toLowerCase().replace(/[_ ]/g, '-');
  if (_room !== room) {
    return res.redirect("/" + _room);
  }
  model = store.createModel();
  return model.subscribe({
    _room: "rooms." + room
  }, 'rooms.*.players', function() {
    if (!model.get('_room.letters')) {
      model.set('_room.letters', JSON.parse(defaultLetters));
    }
    model.set('_roomName', room);
    return model.bundle(function(bundle) {
      var boardHtml, close, id, letter, open, _ref;
      boardHtml = '';
      if (~req.headers['user-agent'].indexOf('MSIE')) {
        open = '<a href=# onclick="return false"';
        close = '</a>';
      } else {
        open = '<span';
        close = '</span>';
      }
      _ref = model.get("_room.letters");
      for (id in _ref) {
        letter = _ref[id];
        boardHtml += "" + open + " draggable=true class=\"" + letter.color + " letter\" id=" + id + "\nstyle=left:" + letter.position.left + "px;top:" + letter.position.top + "px>" + letter.value + close;
      }
      return res.send("<!DOCTYPE html>\n<title>Letters game</title>\n<link rel=stylesheet href=style.css>\n<link rel=stylesheet href=\"http://fonts.googleapis.com/css?family=Anton\">\n<div id=back>\n  <div id=page>\n    <p id=info>\n    <div id=rooms>\n      <p>Rooms:\n      <ul id=roomlist></ul>\n    </div>\n    <div id=board>" + boardHtml + "</div>\n  </div>\n</div>\n<script>init=" + bundle + "</script>\n<script src=script.js></script>");
    });
  });
});
store.sockets.on('connection', function(socket) {
  return socket.on('join', function(room) {
    var playersPath;
    playersPath = "rooms." + room + ".players";
    store.incr(playersPath);
    return socket.on('disconnect', function() {
      return store.incr(playersPath, -1);
    });
  });
});
app.listen(3010);
console.log('Go to http://localhost:3010/lobby');
console.log('Go to http://localhost:3010/powder-room');

==> racer-0.1.3.tgz: package/examples/letters/server.js <==
var app, col, colors, defaultLetters, express, fs, gzip, racer, row, store;

express = require('express');

gzip = require('connect-gzip');

fs = require('fs');

racer = require('racer');

app = express.createServer().use(express.favicon()).use(gzip.staticGzip(__dirname));

store = racer.createStore({
  redis: {
    db: 10
  },
  listen: app,
  namespace: 'letters'
});

store.flush();

racer.js({
  entry: __dirname + '/client.js'
}, function(js) {
  return fs.writeFileSync(__dirname + '/script.js', js);
});

colors = ['red', 'yellow', 'blue', 'orange', 'green'];

defaultLetters = {};

for (row = 0; row <= 4; row++) {
  for (col = 0; col <= 25; col++) {
    defaultLetters[row * 26 + col] = {
      color: colors[row],
      value: String.fromCharCode(65 + col),
      position: {
        left: col * 24 + 72,
        top: row * 32 + 8
      }
    };
  }
}

defaultLetters = JSON.stringify(defaultLetters);

app.get('/:room?', function(req, res) {
  var model, room, _room;
  room = req.params.room;
  if (!(room && /^[-\w ]+$/.test(room))) return res.redirect('/lobby');
  _room = room.toLowerCase().replace(/[_ ]/g, '-');
  if (_room !== room) return res.redirect("/" + _room);
  model = store.createModel();
  return model.subscribe({
    _room: "rooms." + room
  }, 'rooms.*.players', function() {
    if (!model.get('_room.letters')) {
      model.set('_room.letters', JSON.parse(defaultLetters));
    }
    model.set('_roomName', room);
    return model.bundle(function(bundle) {
      var boardHtml, close, id, letter, open, _ref;
      boardHtml = '';
      if (~req.headers['user-agent'].indexOf('MSIE')) {
        open = '<a href=# onclick="return false"';
        close = '</a>';
      } else {
        open = '<span';
        close = '</span>';
      }
      _ref = model.get("_room.letters");
      for (id in _ref) {
        letter = _ref[id];
        boardHtml += "" + open + " draggable=true class=\"" + letter.color + " letter\" id=" + id + "\nstyle=left:" + letter.position.left + "px;top:" + letter.position.top + "px>" + letter.value + close;
      }
      return res.send("<!DOCTYPE html>\n<title>Letters game</title>\n<link rel=stylesheet href=style.css>\n<link rel=stylesheet href=\"http://fonts.googleapis.com/css?family=Anton\">\n<div id=back>\n  <div id=page>\n    <p id=info>\n    <div id=rooms>\n      <p>Rooms:\n      <ul id=roomlist></ul>\n    </div>\n    <div id=board>" + boardHtml + "</div>\n  </div>\n</div>\n<script>init=" + bundle + "</script>\n<script src=script.js></script>");
    });
  });
});

store.sockets.on('connection', function(socket) {
  return socket.on('join', function(room) {
    var playersPath;
    playersPath = "rooms." + room + ".players";
    store.incr(playersPath);
    return socket.on('disconnect', function() {
      return store.incr(playersPath, -1);
    });
  });
});

app.listen(3010);

console.log('Go to http://localhost:3010/lobby');

console.log('Go to http://localhost:3010/powder-room');
